@@ -32,8 +32,14 @@ class Holding(Record):
         if no 'holding_id' is provided, but 'data' is provided and create_holding is True, then
         it creates a new holding.
 
-        :param bib: IzBib object
-        :param holding_id: holding ID
+        :ivar mms_id: record mms_id
+        :ivar holding_id: holding ID
+        :ivar zone: zone of the record
+        :ivar env: environment of the entity: 'P' for production and 'S' for sandbox
+        :ivar bib: class:`almapiwrapper.inventory.IzBib` object
+        :ivar data: :class:`almapiwrapper.record.XmlData`
+        object, useful to force update a record from a backup
+        :ivar create_holding: boolean, if True try to create a new holding (if no 'holding_id' is provided)
         """
         self._items = None
         self.error = False
